# Generated by roxygen2: do not edit by hand

S3method(cgeneric,"function")
S3method(cgeneric,cgeneric)
S3method(cgeneric,character)
S3method(cgeneric,inla.cgeneric)
S3method(is.zero,Matrix)
S3method(is.zero,default)
S3method(is.zero,matrix)
S3method(plot,cgeneric)
S3method(plot,rgeneric)
S3method(print,cgeneric)
S3method(print,rgeneric)
S3method(rgeneric,default)
S3method(rgeneric,inla.rgeneric)
S3method(rgeneric,rgeneric)
S3method(summary,cgeneric)
S3method(summary,rgeneric)
export(Sparse)
export(cgeneric)
export(cgenericBuilder)
export(cgeneric_Q)
export(cgeneric_generic0)
export(cgeneric_graph)
export(cgeneric_iid)
export(cgeneric_initial)
export(cgeneric_mu)
export(cgeneric_prior)
export(cgeneric_shlib_path)
export(findGetFunction)
export(inlaQ)
export(is.zero)
export(multi_generic_model)
export(packageCheck)
export(pcParamCheck)
export(pclrange)
export(pcrange)
export(rgeneric)
export(rgeneric_Q)
export(rgeneric_graph)
export(rgeneric_initial)
export(rgeneric_mu)
export(rgeneric_prior)
export(upperPadding)
exportMethods(kronecker)
importFrom(Matrix,Diagonal)
importFrom(Matrix,as.matrix)
importFrom(Matrix,diag)
importFrom(Matrix,sparseMatrix)
importFrom(graphics,image)
importFrom(methods,as)
importFrom(methods,is)
importFrom(stats,vcov)
importFrom(utils,str)
useDynLib(INLAtools)
