#' Internal to make NAMESPACE
#' @noRd
#' @importFrom methods as is
#' @importFrom stats vcov
#' @importFrom utils str
#' @importFrom graphics image
#' @importFrom Matrix diag Diagonal as.matrix sparseMatrix
#' @useDynLib INLAtools
NULL
